<?php


if ( ! function_exists( 'belly_sanitize_select' ) ) :


	function belly_sanitize_select( $input, $setting ) {

		// Cleanup the input.
		$input = sanitize_text_field( $input );

		// Get list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;

		// If the input is a valid key, return it; otherwise, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'belly_sanitize_checkbox' ) ) :


	function belly_sanitize_checkbox( $checked ) {

		return ( ( isset( $checked ) && true === $checked ) ? true : false );

	}

endif;

if ( ! function_exists( 'belly_sanitize_positive_integer' ) ) :


	function belly_sanitize_positive_integer( $input, $setting ) {

		$input = absint( $input );

		// If the input is an absolute integer, return it.
		// otherwise, return the default.
		return ( $input ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'belly_sanitize_dropdown_pages' ) ) :


	function belly_sanitize_dropdown_pages( $page_id, $setting ) {

		// Ensure $input is an absolute integer.
		$page_id = absint( $page_id );

		// If $page_id is an ID of a published page, return it; otherwise, return the default.
		return ( 'publish' === get_post_status( $page_id ) ? $page_id : $setting->default );

	}

endif;

if ( ! function_exists( 'belly_sanitize_image' ) ) :


	function belly_sanitize_image( $image, $setting ) {

		$mimes = array(
			'jpg|jpeg|jpe' => 'image/jpeg',
			'gif'          => 'image/gif',
			'png'          => 'image/png',
			'bmp'          => 'image/bmp',
			'tif|tiff'     => 'image/tiff',
			'ico'          => 'image/x-icon',
		);

		// Return an array with file extension and mime_type.
		$file = wp_check_filetype( $image, $mimes );

		// If $image has a valid mime_type, return it; otherwise, return the default.
		return ( $file['ext'] ? $image : $setting->default );

	}

endif;


if ( ! function_exists( 'belly_sanitize_number_range' ) ) :


	function belly_sanitize_number_range( $input, $setting ) {

		// Ensure input is an absolute integer.
		$input = absint( $input );

		// Get the input attributes associated with the setting.
		$atts = $setting->manager->get_control( $setting->id )->input_attrs;

		// Get min.
		$min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

		// Get max.
		$max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

		// Get Step.
		$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

		// If the input is within the valid range, return it; otherwise, return the default.
		return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

	}

endif;

if ( ! function_exists( 'belly_sanitize_post_id' ) ) :


	function belly_sanitize_post_id( $post_id, $setting ) {

		// Ensure $input is an absolute integer.
		$post_id = absint( $post_id );

		// If $post_id is an ID of a published post, return it; otherwise, return the default.
		return ( 'publish' === get_post_status( $post_id ) ? $post_id : $setting->default );

	}

endif;

if ( ! function_exists( 'belly_sanitize_textarea' ) ) :


	function belly_sanitize_textarea( $input, $setting ) {

		return wp_kses_post( $input );

	}
endif;
